pub struct EventMetadata { /* private fields */ }Expand description
The event metadata structure is a Arc wrapper around the actual metadata to avoid cloning the
underlying data until it becomes necessary to provide a mut copy.
Implementations
Sourceimpl EventMetadata
impl EventMetadata
Sourcepub fn default_with_value(value: Value) -> EventMetadata
pub fn default_with_value(value: Value) -> EventMetadata
Creates EventMetadata with the given Value, and the rest of the fields with default values
Sourcepub fn secrets_mut(&mut self) -> &mut Secrets
pub fn secrets_mut(&mut self) -> &mut Secrets
Returns a mutable reference to the secrets
Sourcepub fn source_id(&self) -> Option<&Arc<ComponentKey>>
pub fn source_id(&self) -> Option<&Arc<ComponentKey>>
Returns a reference to the metadata source id.
Sourcepub fn source_type(&self) -> Option<&str>
pub fn source_type(&self) -> Option<&str>
Returns a reference to the metadata source type.
Sourcepub fn upstream_id(&self) -> Option<&OutputId>
pub fn upstream_id(&self) -> Option<&OutputId>
Returns a reference to the metadata parent id. This is the OutputId
of the previous component the event was sent through (if any).
Sourcepub fn set_source_id(&mut self, source_id: Arc<ComponentKey>)
pub fn set_source_id(&mut self, source_id: Arc<ComponentKey>)
Sets the source_id in the metadata to the provided value.
Sourcepub fn set_source_type<S>(&mut self, source_type: S)
pub fn set_source_type<S>(&mut self, source_type: S)
Sets the source_type in the metadata to the provided value.
Sourcepub fn set_upstream_id(&mut self, upstream_id: Arc<OutputId>)
pub fn set_upstream_id(&mut self, upstream_id: Arc<OutputId>)
Sets the upstream_id in the metadata to the provided value.
Sourcepub fn datadog_api_key(&self) -> Option<Arc<str>>
pub fn datadog_api_key(&self) -> Option<Arc<str>>
Return the datadog API key, if it exists
Sourcepub fn set_datadog_api_key(&mut self, secret: Arc<str>)
pub fn set_datadog_api_key(&mut self, secret: Arc<str>)
Set the datadog API key to passed value
Sourcepub fn splunk_hec_token(&self) -> Option<Arc<str>>
pub fn splunk_hec_token(&self) -> Option<Arc<str>>
Return the splunk hec token, if it exists
Sourcepub fn set_splunk_hec_token(&mut self, secret: Arc<str>)
pub fn set_splunk_hec_token(&mut self, secret: Arc<str>)
Set the splunk hec token to passed value
Sourcepub fn add_dropped_field(&mut self, meaning: KeyString, value: Value)
pub fn add_dropped_field(&mut self, meaning: KeyString, value: Value)
Adds the value to the dropped fields list. There is currently no way to remove a field from this list, so if a field is dropped and then the field is re-added with a new value - the dropped value will still be retrieved.
Sourcepub fn dropped_field(&self, meaning: impl AsRef<str>) -> Option<&Value>
pub fn dropped_field(&self, meaning: impl AsRef<str>) -> Option<&Value>
Fetches the dropped field by meaning.
Sourcepub fn datadog_origin_metadata(&self) -> Option<&DatadogMetricOriginMetadata>
pub fn datadog_origin_metadata(&self) -> Option<&DatadogMetricOriginMetadata>
Returns a reference to the DatadogMetricOriginMetadata.
Sourcepub fn source_event_id(&self) -> Option<Uuid>
pub fn source_event_id(&self) -> Option<Uuid>
Returns a reference to the event id.
Sourcepub fn last_transform_timestamp(&self) -> Option<Instant>
pub fn last_transform_timestamp(&self) -> Option<Instant>
Returns the timestamp of the last transform buffer enqueue operation, if it exists.
Sourcepub fn set_last_transform_timestamp(&mut self, timestamp: Instant)
pub fn set_last_transform_timestamp(&mut self, timestamp: Instant)
Sets the transform enqueue timestamp to the provided value.
Sourceimpl EventMetadata
impl EventMetadata
Sourcepub fn with_finalizer(self, finalizer: EventFinalizer) -> EventMetadata
pub fn with_finalizer(self, finalizer: EventFinalizer) -> EventMetadata
Replaces the existing event finalizers with the given one.
Sourcepub fn with_finalizers(self, finalizers: EventFinalizers) -> EventMetadata
pub fn with_finalizers(self, finalizers: EventFinalizers) -> EventMetadata
Replaces the existing event finalizers with the given ones.
Sourcepub fn with_batch_notifier(self, batch: &BatchNotifier) -> EventMetadata
pub fn with_batch_notifier(self, batch: &BatchNotifier) -> EventMetadata
Replace the finalizer with a new one created from the given batch notifier.
Sourcepub fn with_batch_notifier_option(
self,
batch: &Option<BatchNotifier>,
) -> EventMetadata
pub fn with_batch_notifier_option( self, batch: &Option<BatchNotifier>, ) -> EventMetadata
Replace the finalizer with a new one created from the given optional batch notifier.
Sourcepub fn with_schema_definition(
self,
schema_definition: &Arc<Definition>,
) -> EventMetadata
pub fn with_schema_definition( self, schema_definition: &Arc<Definition>, ) -> EventMetadata
Replace the schema definition with the given one.
Sourcepub fn with_source_type<S>(self, source_type: S) -> EventMetadata
pub fn with_source_type<S>(self, source_type: S) -> EventMetadata
Replaces the existing source_type with the given one.
Sourcepub fn with_origin_metadata(
self,
origin_metadata: DatadogMetricOriginMetadata,
) -> EventMetadata
pub fn with_origin_metadata( self, origin_metadata: DatadogMetricOriginMetadata, ) -> EventMetadata
Replaces the existing DatadogMetricOriginMetadata with the given one.
Sourcepub fn with_source_event_id(
self,
source_event_id: Option<Uuid>,
) -> EventMetadata
pub fn with_source_event_id( self, source_event_id: Option<Uuid>, ) -> EventMetadata
Replaces the existing source_event_id with the given one.
Sourcepub fn merge(&mut self, other: EventMetadata)
pub fn merge(&mut self, other: EventMetadata)
Merge the other EventMetadata into this.
If a Datadog API key is not set in self, the one from other will be used.
If a Splunk HEC token is not set in self, the one from other will be used.
Sourcepub fn update_status(&self, status: EventStatus)
pub fn update_status(&self, status: EventStatus)
Update the finalizer(s) status.
Sourcepub fn update_sources(&mut self)
pub fn update_sources(&mut self)
Update the finalizers’ sources.
Sourcepub fn finalizers(&self) -> &EventFinalizers
pub fn finalizers(&self) -> &EventFinalizers
Gets a reference to the event finalizers.
Sourcepub fn add_finalizer(&mut self, finalizer: EventFinalizer)
pub fn add_finalizer(&mut self, finalizer: EventFinalizer)
Add a new event finalizer to the existing list of event finalizers.
Sourcepub fn take_finalizers(&mut self) -> EventFinalizers
pub fn take_finalizers(&mut self) -> EventFinalizers
Consumes all event finalizers and returns them, leaving the list of event finalizers empty.
Sourcepub fn merge_finalizers(&mut self, finalizers: EventFinalizers)
pub fn merge_finalizers(&mut self, finalizers: EventFinalizers)
Merges the given event finalizers into the existing list of event finalizers.
Sourcepub fn schema_definition(&self) -> &Arc<Definition>
pub fn schema_definition(&self) -> &Arc<Definition>
Get the schema definition.
Sourcepub fn set_schema_definition(&mut self, definition: &Arc<Definition>)
pub fn set_schema_definition(&mut self, definition: &Arc<Definition>)
Set the schema definition.
Sourcepub fn add_schema_meaning(
&mut self,
target_path: OwnedTargetPath,
meaning: &str,
)
pub fn add_schema_meaning( &mut self, target_path: OwnedTargetPath, meaning: &str, )
Helper function to add a semantic meaning to the schema definition.
This replaces the common code sequence of:
let new_schema = log_event
.metadata()
.schema_definition()
.as_ref()
.clone()
.with_meaning(target_path, meaning);
log_event
.metadata_mut()
.set_schema_definition(new_schema);Trait Implementations
Sourceimpl ByteSizeOf for EventMetadata
impl ByteSizeOf for EventMetadata
Sourceimpl Clone for EventMetadata
impl Clone for EventMetadata
Sourcefn clone(&self) -> EventMetadata
fn clone(&self) -> EventMetadata
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EventMetadata
impl Debug for EventMetadata
Sourceimpl Default for EventMetadata
impl Default for EventMetadata
Sourcefn default() -> EventMetadata
fn default() -> EventMetadata
Sourceimpl<'de> Deserialize<'de> for EventMetadata
impl<'de> Deserialize<'de> for EventMetadata
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<EventMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<EventMetadata, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl EventDataEq for EventMetadata
impl EventDataEq for EventMetadata
fn event_data_eq(&self, _other: &EventMetadata) -> bool
Sourceimpl From<EventMetadata> for Metadata
impl From<EventMetadata> for Metadata
Sourcefn from(value: EventMetadata) -> Metadata
fn from(value: EventMetadata) -> Metadata
Sourceimpl From<Metadata> for EventMetadata
impl From<Metadata> for EventMetadata
Sourcefn from(value: Metadata) -> EventMetadata
fn from(value: Metadata) -> EventMetadata
Sourceimpl PartialEq for EventMetadata
impl PartialEq for EventMetadata
Sourceimpl Serialize for EventMetadata
impl Serialize for EventMetadata
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,